@@ -1,4 +1,4 @@
-class CorrelationIdNotProvidedException(BaseException):
+class CorrelationIdNotProvidedException(Exception):
     pass
 
 
@@ -6,9 +6,10 @@ class DjangoStompImproperlyConfigured(Exception):
     pass
 
 
-class DjangoStompIncorrectUse(BaseException):
+class DjangoStompIncorrectUse(Exception):
     """
     Raised when Django stomp has been invoked in a wrong manner such as
     less arguments than it needs, etc.
     """
-    pass
\ No newline at end of file
+
+    pass
